
from evaluate import Experiment
from metrics import MetricEval

from methods import PARC, kNN, LogME, HSIC, CKA, Target_Alignment, DDS, KITE, RSA, LEEP, SplitLogistic, NegativeCrossEntropy, HScore

import argparse


parser = argparse.ArgumentParser(description='KTIE')

parser.add_argument('--n_dims', default=32, type=int,  help='feature dimension')

parser.add_argument('--budget', default=500, type=int,  help='budget')

parser.add_argument('--init', default="he_normal", type=str,  help='budget')

args = parser.parse_args()

my_methods = {

	'NCE': NegativeCrossEntropy(),	
	'LEEP': LEEP(n_dims=args.n_dims),
	'LogME': LogME(n_dims=args.n_dims),
	
	'HScore': HScore(n_dims=args.n_dims),
	'RSA': RSA(n_dims=args.n_dims),
	'DDS': DDS(n_dims=args.n_dims),
	'PARC': PARC(n_dims=args.n_dims),
	
	'SplitLogistic': SplitLogistic(n_dims=args.n_dims),
	'1-NN CV'  : kNN(k=1, n_dims=args.n_dims),
	'5-NN CV'  : kNN(k=5, n_dims=args.n_dims),

	'CKA': CKA(n_dims=args.n_dims),
	'HSIC': HSIC(n_dims=args.n_dims),
	'Target_Alignment':  Target_Alignment(n_dims=args.n_dims),
	
	"KTIE": KITE(n_dims=args.n_dims)
}


experiment = Experiment(my_methods, name='budget_' + str(args.budget) + '_n_dims_' + str(args.n_dims), runs=3, budget=args.budget, append=False) 
                                                               
experiment.run(args.init)                                               

metric = MetricEval(experiment.out_file)                       


mean, variance, _all = metric.aggregate(metric="pearson")      

print(mean)
print (variance)